@@ -95,10 +95,10 @@ end
 @qubitop1 Z            (x   ,z   , x!=0)
 @qubitop1 SQRTX        (x⊻z ,z   , x==0 && z!=0)
 @qubitop1 InvSQRTX     (x⊻z ,z   , x!=0 && z!=0)
-@qubitop1 SQRTY        (z   ,x   , z==0)
+@qubitop1 SQRTY        (z   ,x   , x!=0 && z==0)
 @qubitop1 InvSQRTY     (z   ,x   , z!=0 && x==0)
-@qubitop1 CXYZ         (x⊻z ,x   , z==0 && x==0)
-@qubitop1 CZYX         (z   ,x⊻z , z==0 && x==0)
+@qubitop1 CXYZ         (x⊻z ,x   , false)
+@qubitop1 CZYX         (z   ,x⊻z , false)
 
 """A "symbolic" single-qubit Identity operation.
 
@@ -384,7 +384,7 @@ function Base.show(io::IO, op::AbstractTwoQubitOperator)
     if get(io, :compact, false) | haskey(io, :typeinfo)
         print(io, "$(string(typeof(op)))($(op.q1),$(op.q2))")
     else
-        print(io, "$(string(typeof(op))) on qubit1 ($(op.q1),$(op.q2))\n")
+        print(io, "$(string(typeof(op))) on qubit ($(op.q1),$(op.q2))\n")
         show(io, CliffordOperator(op,2;compact=true))
     end
 end
